@@ -8,6 +8,10 @@
 /* grad() or switchfunctions(), directly or indirectly.                  	*/
 /***************************************************************************/
 
+/* define globals */
+globaldatatype global_data;
+globalRdatatype r_stuff;
+
 
 /***************************************************************************/
 /*             Problem specific routines                                   */
